@@ -1,4 +1,3 @@
-
 #' @name +.TelegramObject
 #' @rdname TelegramObject-add
 #' @aliases add
@@ -78,11 +77,12 @@
       call. = FALSE
     )
   } else {
-    stop(sprintf(
-      "Cannot add `%s` and `%s` objects together.",
-      class(e1), class(e2)
-    ),
-    call. = FALSE
+    stop(
+      sprintf(
+        "Cannot add `%s` and `%s` objects together.",
+        class(e1), class(e2)
+      ),
+      call. = FALSE
     )
   }
 
@@ -96,7 +96,7 @@
 #' @docType class
 #' @name TelegramObject
 #' @aliases is.TelegramObject
-#' @format An \code{\link{R6Class}} generator object.
+#' @format An \code{\link[R6]{R6Class}} generator object.
 #' @export
 TelegramObject <- R6::R6Class("TelegramObject")
 
